__version__ = "0.1.0"
__doc__ = """
This is a small package that provides 3 high-level APIs to interact elegantly with stdin, stdout and stderr:

    - stdin
    - stderr
    - stdout

You can use it as such:

if __name__ == "__main__":
    stdin | print
    "This prints out stuff on stdout" | stdout
    "This prints out stuff on stderr" | stderr
"""

import io
from sys import stdin as stdin_fd, stderr as stderr_fd, stdout as stdout_fd


class STDWrapper:
    def __init__(self, fd):
        self.fd: io.TextIOWrapper = fd

    def __or__(self, other):
        return other.__call__(str(self))

    def __ror__(self, other):
        if not self.fd.writable():
            raise ValueError(f"{self.fd.name} is not writable")
        return self.fd.write(other)

    def __str__(self):
        if self.fd.readable():
            return self.fd.read()
        return self.fd.name


stdin = STDWrapper(stdin_fd)
stdout = STDWrapper(stdout_fd)
stderr = STDWrapper(stderr_fd)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['stds']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'stds',
    'version': '0.1.1',
    'description': 'A module for interacting with stdin, stdout and stderr.',
    'long_description': '# stds\n\n## Motivation\n\nThis is a small package that provides 3 high-level APIs to interact elegantly with stdin, stdout and stderr:\n\n    - stdin\n    - stderr\n    - stdout\n\n## Usage\n\nYou can use it as such:\n\n``` \nif __name__ == "__main__":\n    stdin | print\n    "This prints out stuff on stdout" | stdout\n    "This prints out stuff on stderr" | stderr\n```\n',
    'author': '4thel00z',
    'author_email': '4thel00z@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/4thel00z/std',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3,<4',
}


setup(**setup_kwargs)
